#!/usr/bin/env python
from distutils.core import setup

setup(
    name="pytwwa5",
    version="0.1",
    description="Our first Python distribution package",
    author="Unknown",
    author_email = "unknown@gmail.com"
)
